<?xml version="1.0" encoding="UTF-8"?>
<!--*******************************************************************************
*
* Licensed Material - Property of IBM
*
* 5655-002
*
* (C) Copyright IBM Corp. 2006
*                                                                           
*   US Government Users Restricted Rights - Use, duplication or
*   disclosure restricted by GSA ASP Schedule Contract with
*   IBM Corp.
*                                                                         
*                                                                           
* MODULE NAME= docx2fo.xslt                                                 
*                                                                           
* DESCRIPTIVE NAME= Convert the result of the DCF to DCFDocument conversion to xsl:fo input.                  
*                                                                           *                                                                           
* Author: Dieter Gottschall
*                                                                           
* Change Activity:                                                          
*                                                                           
*	Code		Release 	Date				Person		Reason                                    
*	@00			121/122	2006-10-20	GOT			PTR5934 Initial Release	
*****************************************************************************************-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="no" standalone="yes" omit-xml-declaration="no"/>
	<!--******************************************************************************* -->
	<!--* Global variables							                                * -->
	<!--******************************************************************************* -->
	<xsl:variable name="g-space" select="' '"/>
	<!--******************************************************************************* -->
	<!--* Build the hashtable for the global parms		                           * -->
	<!--******************************************************************************* -->
	<xsl:key name="all-parms" match="Parm" use="concat(concat(parent::node()/@seq, '-'), @name)"/>
	<!--******************************************************************************* -->
	<!--* Get rid of whitespace between XML/HTML Tags                           * -->
	<!--******************************************************************************* -->
	<xsl:strip-space elements="*"/>
	<xsl:template match="GlobalParms"/>
	<xsl:template match="LocalParms"/>
	<xsl:template match="Title"/>
	<xsl:attribute-set name="fo-H1">
		<xsl:attribute name="font-size">24pt</xsl:attribute>
		<xsl:attribute name="font-family">sans-serif</xsl:attribute>
		<xsl:attribute name="font-weight">bold</xsl:attribute>
		<xsl:attribute name="color">blue</xsl:attribute>
	</xsl:attribute-set>
	<xsl:attribute-set name="fo-GML">
		<xsl:attribute name="font-size">12pt</xsl:attribute>
		<xsl:attribute name="font-family">sans-serif</xsl:attribute>
		<xsl:attribute name="color">black</xsl:attribute>
	</xsl:attribute-set>
	<!--******************************************************************************* -->
	<!--* Do the root (document thing)                                                * -->
	<!--* - an HTML document is created, with head and meta                           * -->
	<!--* - then the BODY with the CONFIGSECTION and all the styles                   * -->
	<!--******************************************************************************* -->
	<xsl:template match="ASFDoc">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
			<fo:layout-master-set>
				<fo:simple-page-master master-name="straight-A4" page-height="297mm" page-width="210mm" margin-top="20mm" margin="20mm" margin-left="25mm" margin-right="25mm">
					<fo:region-body margin-bottom="25mm" margin-top="50mm"/>
					<fo:region-after region-name="xsl-footer" extent="15mm" border-top-width="2mm" border-top-color="red" border-top-style="double"/>
					<fo:region-before region-name="xsl-header" extent="50mm" border-top-width="2mm" border-top-color="red" border-top-style="double"/>
				</fo:simple-page-master>
			</fo:layout-master-set>
			<fo:page-sequence master-reference="straight-A4">
				<fo:static-content flow-name="xsl-footer">
					<fo:block font-size="8pt" padding-before="2mm" text-align="center" border-top-width="0.2mm" border-top-color="gray" border-top-style="solid">Seite <fo:page-number/>
					</fo:block>
				</fo:static-content>
				<fo:static-content flow-name="xsl-header">
					<fo:block font-size="10pt" text-align="center" border-bottom-width="0.2mm" border-bottom-color="gray" border-bottom-style="solid">
						<fo:external-graphic src="experto.gif" scaling="uniform" width="50%" height="35mm" content-height="30mm" content-width="40mm"/>
					</fo:block>
				</fo:static-content>
				<fo:flow flow-name="xsl-region-body">
					<fo:block text-align="justify">
						<xsl:apply-templates/>
					</fo:block>
				</fo:flow>
			</fo:page-sequence>
		</fo:root>
	</xsl:template>
	<xsl:template match="H1">
		<fo:block xsl:use-attribute-sets="fo-GML">
			<xsl:apply-templates/>
		</fo:block>
	</xsl:template>
	<xsl:template match="P">
		<fo:block xsl:use-attribute-sets="fo-GML" padding-before="3mm">
			<xsl:apply-templates/>
		</fo:block>
	</xsl:template>
	<xsl:template match="HP2">
		<fo:inline font-weight="bold">
			<xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	<xsl:template match="OL | UL">
		<fo:block padding-before="3mm">
			<fo:list-block start-indent="5mm" provisional-distance-between-starts="10mm">
				<xsl:apply-templates/>
			</fo:list-block>
		</fo:block>
	</xsl:template>
	<xsl:template match="LI">
		<fo:list-item>
			<fo:list-item-label end-indent="label-end()">
				<xsl:choose>
					<xsl:when test="parent::UL">
						<fo:block>&#x2022;</fo:block>
					</xsl:when>
					<xsl:when test="parent::OL">
						<fo:block>
							<xsl:value-of select="position()"/>
							<xsl:text>.</xsl:text>
						</fo:block>
					</xsl:when>
				</xsl:choose>
			</fo:list-item-label>
			<fo:list-item-body start-indent="body-start()">
				<fo:block>
					<xsl:apply-templates/>
				</fo:block>
			</fo:list-item-body>
		</fo:list-item>
	</xsl:template>
	<xsl:template match="textblock">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="le">
		<xsl:text> </xsl:text>
	</xsl:template>
	<xsl:template match="Parmref">
		<xsl:variable name="n-current-seq" select="number(ancestor::ASFSP/@seq)"/>
		<fo:inline color="gray">
			<xsl:call-template name="get-value">
				<xsl:with-param name="p-curr-seq" select="$n-current-seq"/>
				<xsl:with-param name="p-look-seq" select="$n-current-seq"/>
				<xsl:with-param name="p-sname" select="@name"/>
			</xsl:call-template>
		</fo:inline>
		<xsl:if test="ancestor::FO-OFF">
			<fo:block/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="CE-ON">
		<fo:block text-align="center">
			<xsl:apply-templates/>
		</fo:block>
	</xsl:template>
	<xsl:template match="FO-OFF">
		<fo:block>
			<xsl:apply-templates/>
		</fo:block>
	</xsl:template>
	<xsl:template match="FO-RIGHT">
		<fo:block text-align="right">
			<xsl:apply-templates/>
		</fo:block>
	</xsl:template>
	<xsl:template match="SK">
		<xsl:variable name="s-padding" select="."/>
		<xsl:choose>
			<xsl:when test="$s-padding">
				<xsl:element name="fo:block">
					<xsl:attribute name="padding"><xsl:value-of select="concat(string($s-padding), 'mm')"/></xsl:attribute>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<fo:block/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="BR">
		<fo:block/>
	</xsl:template>
	<!--
	<xsl:template match="Q">
		<fo:inline font-style="italic" letter-spacing="1mm">
			<xsl:apply-templates/>
		</fo:inline>
	</xsl:template>
	-->
	<xsl:include href="docx2focallables.xsl"/>
	<xsl:include href="../custom/docfocustom1.xsl"/>
</xsl:stylesheet>
