<?xml version="1.0" encoding="UTF-8"?>
<!--*******************************************************************************
*
* Licensed Material - Property of IBM
*
* 5655-002
*
* (C) Copyright IBM Corp. 2003
*                                                                           
*   US Government Users Restricted Rights - Use, duplication or
*   disclosure restricted by GSA ASP Schedule Contract with
*   IBM Corp.
*                                                                         
*                                                                           
* MODULE NAME= docd2hdcf.xsl                                               
*                                                                           
* DESCRIPTIVE NAME= Template dealing with the processing of dcf controls     
*                                                                           
* Description: This style sheet was originally part of the huge docd2h stylesheet.
*              As a result of a major rework involving modularization of that stylesheet
*              the callable templates were separated out
*                                                                           
* Author: Dieter Gottschall
*                                                                           
* Change Activity:                                                          
*                                                                           
* Code		Release 	Date		Person		Reason                                    
*
* @00=		1.0.0		2003-05-20	GOT		Creation as part of a major rework
* @01=		1.0.0		2003-06-30	GOT		PTR2902 don't make DCF Controls and comments bold         
* @02=		1.1.6		2004-06-04	GOT		PTR3050 CT/SYZEICHTEST.
*****************************************************************************************-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="no" standalone="yes" omit-xml-declaration="no"/>
	<!--******************************************************************************* -->
	<!--* DCF Control stuff and specifics. All of them are selected by their          * -->
	<!--* containing XML object, which is a dcfblock                                  * -->
	<!--* - then the BODY with the CONFIGSECTION and all the styles                   * -->
	<!--******************************************************************************* -->
	<!--*                                                                             * -->
	<!--*                                                                             * -->
	<!--******************************************************************************* -->
	<!--* Line breakers, like br, sp, sk                                              * -->
	<!--******************************************************************************* -->
	<!--*                                                                             * -->
	<!--******************************************************************************* -->
	<!--* .br       ignore the first one, for all the others create an HTML BR        * -->
	<!--******************************************************************************* -->
	<xsl:template match="dcfblock/BR">
		<xsl:if test="$p-trace = 'Yes'">
			<xsl:message>BR Block hit</xsl:message>
			<xsl:message>
				<xsl:value-of select="."/>
			</xsl:message>
		</xsl:if>
		<xsl:if test="@lbcount != '-1'">
			<BR/>
		</xsl:if>
	</xsl:template>
	<!--******************************************************************************* -->
	<!--* .cm       Source may be .cm or in most cases .*                             * -->
	<!--******************************************************************************* -->
	<xsl:template match="CM">
		<xsl:variable name="space" select="' '"/>
		<xsl:choose>
			<xsl:when test="@origin = '*'">
				<xsl:variable name="ivalue">
					<xsl:text>.*</xsl:text>
					<xsl:value-of select="."/>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="name(preceding-sibling::node()[position() = 1]) != 'CM'">
						<xsl:element name="DIV">
							<xsl:call-template name="generate-comment-block">
								<xsl:with-param name="pn0" select="position()"/>
								<xsl:with-param name="pn1" select="0"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="dcfcontrol"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="CM" mode="mode-cm">
		<xsl:variable name="ivalue">
			<xsl:text>.*</xsl:text>
			<xsl:value-of select="."/>
		</xsl:variable>
		<xsl:if test="name(preceding-sibling::node()[position() = 1]) = 'CM'">
			<xsl:element name="P">
				<xsl:attribute name="class"><xsl:text>edicomm</xsl:text></xsl:attribute>
				<xsl:value-of select="$ivalue"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<!--******************************************************************************* -->
	<!--* .ct       Make the text editable										   * -->
	<!--******************************************************************************* -->
	<xsl:template match="dcfblock/HW">
		<xsl:variable name="v-tag" select="name(.)"/>
		<xsl:if test="$p-trace = 'Yes'">
			<xsl:message>CT or HW hit
				<xsl:value-of select="$v-tag"/>
			</xsl:message>
			<xsl:message>
				<xsl:value-of select="."/>
			</xsl:message>
		</xsl:if>
		<xsl:variable name="space" select="' '"/>
		<!-- Get the contents into a variable -->
		<xsl:variable name="ivalue">
			<xsl:text>.</xsl:text>
			<xsl:value-of select="$v-tag"/>
			<xsl:value-of select="$space"/>
			<xsl:value-of select="."/>
		</xsl:variable>
		<xsl:message>
			<xsl:value-of select="$ivalue"/>
		</xsl:message>
		<!-- We create the DIV, depending on the commenteditable attribute -->
		<xsl:element name="DIV">
			<xsl:attribute name="class">edicomm</xsl:attribute>
			<xsl:attribute name="contenteditable"><xsl:value-of select="$p-speditable"/></xsl:attribute>
			<xsl:choose>
				<xsl:when test="$p-e-innerdivs = 'Yes'">
					<xsl:element name="DIV">
						<xsl:attribute name="class">innerdiv</xsl:attribute>
						<xsl:value-of select="$ivalue"/>
					</xsl:element>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="P">
						<xsl:attribute name="class"><xsl:text>nowrapparag</xsl:text></xsl:attribute>
						<xsl:value-of select="$ivalue"/>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	<xsl:template match="CT">
		<xsl:element name="DIV">
			<xsl:attribute name="class">edicomm</xsl:attribute>
			<xsl:attribute name="contenteditable"><xsl:value-of select="$p-speditable"/></xsl:attribute>
			<xsl:element name="P">
				<xsl:attribute name="class">nowrapparag</xsl:attribute>
				<xsl:text>.</xsl:text>
				<xsl:value-of select="name(.)"/>
				<xsl:value-of select="$g-space"/>
				<xsl:choose>
					<xsl:when test="$p-v-gray = 'Y'">
						<xsl:call-template name="gray-vars">
							<xsl:with-param name="text-line">
								<xsl:value-of select="string(.)"/>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="$p-v-protect != 'Y'">
						<xsl:value-of select="string(.)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="protect-vars">
							<xsl:with-param name="text-line">
								<xsl:value-of select="string(.)"/>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!--******************************************************************************* -->
	<!--* DOTDOT     Is the replacement for ..                                        * -->
	<!--******************************************************************************* -->
	<xsl:template match="dcfblock/DOTDOT">
		<xsl:if test="$p-trace = 'Yes'">
			<xsl:message>DOTDOT hit</xsl:message>
			<xsl:message>
				<xsl:value-of select="."/>
			</xsl:message>
		</xsl:if>
		<DIV class="dcfc" disabled="disabled">
			<!-- Get the contents into a variable -->
			<xsl:variable name="ivalue">
				<xsl:text>.</xsl:text>
				<xsl:value-of select="."/>
			</xsl:variable>
			<xsl:value-of select="$ivalue"/>
		</DIV>
	</xsl:template>
	<!--******************************************************************************* -->
	<!--* NOXML is anything invalid                                        * -->
	<!--******************************************************************************* -->
	<xsl:template match="dcfblock/NOXML">
		<xsl:if test="$p-trace = 'Yes'">
			<xsl:message>NOXML hit</xsl:message>
			<xsl:message>
				<xsl:value-of select="."/>
			</xsl:message>
		</xsl:if>
		<DIV class="dcfc" disabled="disabled">
			<!-- Get the contents into a variable -->
			<xsl:variable name="ivalue">
				<xsl:text>.</xsl:text>
				<xsl:value-of select="."/>
			</xsl:variable>
			<xsl:value-of select="$ivalue"/>
		</DIV>
	</xsl:template>
	<!--******************************************************************************* -->
	<!--* .se        Requires special processing concerning quotes                    * -->
	<!--******************************************************************************* -->
	<xsl:template match="dcfblock/SE">
		<xsl:if test="$p-trace = 'Yes'">
			<xsl:message>SE hit</xsl:message>
			<xsl:message>
				<xsl:value-of select="."/>
			</xsl:message>
		</xsl:if>
		<!-- Have a space in a variable -->
		<xsl:variable name="space" select="' '"/>
		<xsl:variable name="squote" select="''"/>
		<!-- We create the DIV -->
		<DIV class="dcfc" disabled="disabled">
			<!-- Get the contents into a variable -->
			<xsl:variable name="ivalue">
				<xsl:text>.</xsl:text>
				<xsl:value-of select="name()"/>
				<xsl:value-of select="$space"/>
				<xsl:value-of disable-output-escaping="no" select="."/>
			</xsl:variable>
			<xsl:value-of select="$ivalue"/>
		</DIV>
	</xsl:template>
	<!--******************************************************************************* -->
	<!--* .df        Requires special processing concerning quotes                    * -->
	<!--******************************************************************************* -->
	<xsl:template match="dcfblock/DF">
		<xsl:if test="$p-trace = 'Yes'">
			<xsl:message>DF hit</xsl:message>
			<xsl:message>
				<xsl:value-of select="."/>
			</xsl:message>
		</xsl:if>
		<!-- Have a space in a variable -->
		<xsl:variable name="space" select="' '"/>
		<xsl:variable name="squote" select="''"/>
		<!-- We create the DIV -->
		<DIV class="dcfc" disabled="disabled">
			<!-- Get the contents into a variable -->
			<xsl:variable name="ivalue">
				<xsl:text>.</xsl:text>
				<xsl:value-of select="name()"/>
				<xsl:value-of select="$space"/>
				<xsl:value-of disable-output-escaping="no" select="."/>
			</xsl:variable>
			<xsl:value-of select="$ivalue"/>
		</DIV>
	</xsl:template>
</xsl:stylesheet>
