<?xml version="1.0" encoding="UTF-8"?>
<!-- 
*
**********************************************************************    
*  
*   Licensed Material - Property of IBM                               
*   5655-002                                                          
*                                                                     
*   (C) Copyright IBM Corp. 2003   All Rights Reserved                
*                                                                     
*   US Government Users Restricted Rights - Use, duplication or       
*   disclosure restricted by GSA ASP Schedule Contract with           
*   IBM Corp.    
*
**********************************************************************
*
*
* 	docqpreview.xsl
*
* 	Purpose: Convert the ASF preview XML datastream to displayable HTML
*
*	Description: The ASF preview datastream contains information about paragraphs (the original SPs),
*		rudimentary formatting information (bold, underscore, overstrike),
*		information about lines and pages
*		information about variables and their values and
*		potentially DCF error messages.
*
*		This input is transformed to HTML reflecting all the information:
*		(1) Paragraphs toggle their color
*		(2) Page breaks are horizontal lines
*		(3) Variables (name and value) have a different backgroung color
*		(4) DCF messages are displayed at the end of the document
*
* Change Activity:
*
* Code			Release		Date		Person	Reason
* @01			2002-04-02	GOT	PTR0401 Size and title
* @02			2002-04-11	GOT	PTR0695 Different place for 'linelen'
* @03			2002-07-29	GOT	PTR1821 Apply tag name and attribute shortening
* @04			2002-11-16	GOT	PTR2196 language attribute
* @05			2003-03-12	HSN	PTR3154 unexpected key events
* @06	1.1.6	2003-11-25	UZeh	APAR PQ81380 PTR3875 fnSizeMe has two parameters  
* @07	1.1.6	2004-06-14	GOT	PQ89882 Color coding based on host settings
* @08	1.1.6	2005-04-22	GOT		PK03543 oc contents displayed	
* @09 1.2.2 2006-04-10  MMar  DPK22286 Encoding changed to UTF-8 
*
*
*
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <!-- @09 -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:strip-space elements="Para"/>
	<!-- Ouput the surrounding HTML -->
	<xsl:template match="/">
		<html>
			<xsl:attribute name="lang"><xsl:value-of select="//OLi/@lang"/></xsl:attribute>
			<head>
				<title>
					<!-- Pick the right title, we got some of them -->
					<xsl:value-of select="//QPrv/Ref/Titl"/>
				</title>
			</head>
			<xsl:element name="body">
				<xsl:attribute name="Lang"><xsl:value-of select="//OLi/@lang"/></xsl:attribute>
				<xsl:apply-templates/>
				<xsl:call-template name="qerrs"/>
			</xsl:element>
		</html>
	</xsl:template>
	<!-- Make sure Title and Paragraph Title don't appear in Text -->
	<xsl:template match="Titl"/>
	<xsl:template match="PTit"/>
	<xsl:template match="dcfm"/>
	<!-- Process Paragraph 
	* Simply create a span with a class of qpara with a {}-pair as paragraph separator
	-->
	<xsl:template match="Para">
		<xsl:variable name="ipcount">
			<xsl:number count="Para" level="any"/>
		</xsl:variable>
		<xsl:element name="span">
			<xsl:attribute name="class"><xsl:text>qpara</xsl:text><xsl:number value="$ipcount mod 2"/></xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	<!-- Process Line 
	* Simply create a br to display the line as a line
	-->
	<xsl:template match="Line">
		<xsl:apply-templates/>
		<br/>
	</xsl:template>
	<!-- Process bold 
	* Simply create a strong tag pair
	-->
	<xsl:template match="bold">
		<strong>
			<xsl:apply-templates/>
		</strong>
	</xsl:template>
	<xsl:template match="CHANGED">
		<xsl:element name="SPAN">
			<xsl:attribute name="style"><xsl:value-of select="@style"/></xsl:attribute>
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	<!-- Process us 
	* Simply create a u tag pair
	-->
	<xsl:template match="us">
		<u>
			<xsl:apply-templates/>
		</u>
	</xsl:template>
	<!-- Process us 
	* Simply create a u tag pair
	-->
	<xsl:template match="os">
		<strike>
			<xsl:apply-templates/>
		</strike>
	</xsl:template>
	<!-- Process Pagebreak 
	* Simply create an hr
	-->
	<xsl:template match="PBr">
		<hr/>
		<xsl:apply-templates/>
	</xsl:template>
	<!-- Process Variable 
	* Create an Outer span for the variable and inner spans for name and value
	-->
	<xsl:template match="dcfvar">
		<span class="qvar">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	<xsl:template match="dcfvname">
		<span class="qvname">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	<xsl:template match="dcfvvalue">
		<span class="qvvalue">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	<xsl:template match="OC">
		<xsl:choose>
			<xsl:when test="@disp = 'Y'">
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:otherwise/>
		</xsl:choose>
	</xsl:template>
	<!-- Process Error messages -->
	<xsl:template name="qerrs">
		<hr/>
		<xsl:if test=".//dcfm!=''">
			<xsl:text>DCF Messages</xsl:text>
			<br/>
			<xsl:for-each select=".//dcfm">
				<xsl:value-of select="."/>
				<br/>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
