<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:template match="PeekXML">
		<html>
			<head>
				<title>Peek Output</title>
				<style>
				body {font-family:Verdana; font-size:0.8em}
				table {font-family:Verdana; font-size:0.8em}
				h3 {font-size:0.8em}
				.endpoint {background-color:cyan}
				.stringval {color:white;background-color:green}
				.excep {color:white;background-color:red}
				.sep {background-color:black;height:0.2em}
				</style>
			</head>
			<body>
				<xsl:apply-templates select="LookupResult"/>
				<xsl:apply-templates select="WASVars"/>
				<xsl:for-each select="//Context">
					<h3>
						<xsl:text>Context (</xsl:text>
						<xsl:value-of select="./ContextName/@level"/>
						<xsl:text>): </xsl:text>
						<xsl:value-of select="./ContextName"/>
					</h3>
					<table border="1">
						<tbody>
							<xsl:apply-templates/>
						</tbody>
					</table>
				</xsl:for-each>
				<xsl:apply-templates select="SystemProps"/>
			</body>
		</html>
	</xsl:template>
	<xsl:template match="Context">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="ContextName">
	</xsl:template>
	<xsl:template match="Element">
		<xsl:apply-templates/>
	</xsl:template>
	<xsl:template match="BindingName">
		<tr class="sep">
			<td width="30%"> </td>
			<td width="70%"> </td>
		</tr>
		<xsl:element name="tr">
			<xsl:if test="string(../ClassName) != 'javax.naming.Context'">
				<xsl:attribute name="class">endpoint</xsl:attribute>
			</xsl:if>
			<td>BindigName</td>
			<td>
				<xsl:apply-templates/>
			</td>
		</xsl:element>
	</xsl:template>
	<xsl:template match="ClassName">
		<xsl:element name="tr">
			<xsl:if test="string(.) != 'javax.naming.Context'">
				<xsl:attribute name="class">endpoint</xsl:attribute>
			</xsl:if>
			<td>ClassName</td>
			<td>
				<xsl:apply-templates/>
			</td>
		</xsl:element>
	</xsl:template>
	<xsl:template match="StringValue">
		<tr class="stringval">
			<td>StringValue</td>
			<td>
				<xsl:apply-templates/>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="LookupResult">
		<h3>Lookup Result</h3>
		<xsl:value-of select="./LookupName"/>
		<xsl:text>=</xsl:text>
		<xsl:value-of select="./LookupValue"/>
	</xsl:template>
	<xsl:template match="ToStringValue"/>
	<xsl:template match="NamingException">
		<tr class="excep">
			<td>Exception, 
			Context:
			<xsl:value-of select="../ContextName"/>
			</td>
			<td>
				<xsl:apply-templates/>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="SystemProps">
		<h2>System Properties</h2>
		<table border="1">
			<tbody>
				<xsl:apply-templates/>
			</tbody>
		</table>
	</xsl:template>
	<xsl:template match="Property">
		<tr>
			<xsl:apply-templates/>
		</tr>
	</xsl:template>
	<xsl:template match="PropName | PropClassName | PropVal">
		<td>
			<xsl:apply-templates/>
		</td>
	</xsl:template>
	<xsl:template match="WASVars">
		<h2>WebSphere Variables</h2>
		<table border="1">
			<tbody>
				<xsl:apply-templates/>
			</tbody>
		</table>
	</xsl:template>
	<xsl:template match="VarObj">
		<tr>
			<xsl:apply-templates/>
		</tr>
	</xsl:template>
	<xsl:template match="VarClassName | VarStringVal | WASVarname | WASVarvalue">
		<td>
			<xsl:apply-templates/>
		</td>
	</xsl:template>
</xsl:stylesheet>
